@@ -218,6 +218,8 @@ def _construct_serializer(serializer_prefix: str, serializer_suffix: str,
                 ret = after_list_callback(self.context['request'], {'results': [ret]})['results'][0]
             return ReturnDict(ret, serializer=self)
 
+    if resource_name == 'app_info':
+        print('TTWWW', serializer_prefix, serializer_suffix)
     new_serializer = type(f'{serializer_prefix}{resource_name}Serializer{serializer_suffix}', (GenericSerializer,), {
         **{custom_field.name: serializers.SerializerMethodField(read_only=True) for custom_field in
            custom_fields},
