@@ -99,6 +99,8 @@ class JsonApiModelViewBuilder:
             self._queryset = queryset
         self._spice_queryset = permitted_objects
         self._skip_plugins = skip_plugins if skip_plugins is not None else [plugins.AUTO_ADMIN_VIEWS]
+        if plugins.AUTO_ADMIN_VIEWS not in self._skip_plugins:
+            self._skip_plugins.append(plugins.AUTO_ADMIN_VIEWS)
         include_plugins = include_plugins or []
         for item in include_plugins:
             if item in self._skip_plugins:
@@ -293,16 +295,11 @@ class JsonApiModelViewBuilder:
         admin_builder = deepcopy(self)
         admin_builder._skip_plugins = [plugins.AUTO_ADMIN_VIEWS]
         admin_builder._spice_queryset = None
-        admin_builder._resource_name = f'admin_view_{admin_builder._resource_name.replace("admin_view_", "")}'
+        admin_builder._resource_name = f'{admin_builder._resource_name}'
         admin_permission_class = admin_builder._plugin_options.get(plugins.AUTO_ADMIN_VIEWS, {}).get(
             'ADMIN_PERMISSION_CLASS')
         admin_builder._is_admin = True
 
-        for limit_to_on_retrieve in [False, True]:
-            if limit_to_on_retrieve in admin_builder._relations:
-                for relation in admin_builder._relations[limit_to_on_retrieve]:
-                    relation.resource_name = f'admin_view_{relation.resource_name.replace("admin_view_", "")}'
-
         if admin_permission_class is not None:
             admin_builder._permission_classes = [*admin_builder._permission_classes, admin_permission_class]
 
